@@ -35,9 +35,9 @@ GetSequences <- function(ProteinAccList, directorypath = NULL){
     #columns = what to return from all of the information (see: https://www.uniprot.org/help/uniprotkb_column_names)
     ProteinName_url <- paste0("?query=accession:",ProteinAcc,"&format=tab&columns=",columns)
     RequestUrl <- paste0(baseUrl , ProteinName_url)
+    RequestUrl <- URLencode(RequestUrl)
     if (Request$status_code == 200){
       # parse the information in DataFrame
-      Test <- read.table(RequestUrl, header = TRUE, sep = '\t')
       ProteinDataTable <- tryCatch(read.table(RequestUrl, header = TRUE, sep = '\t'), error=function(e) NULL)
       if (!is.null(ProteinDataTable))
       {
